EcanDbParams
=============================================================

This git repository contains the EcanDbParams package for getting the appropriate sql parameters for the package `pdsql <http://pdsql.readthedocs.io>`_.

Installation
------------
EcanDbParams can be installed via pip or conda::

  pip install EcanDbParams

or::

  conda install -c mullenkamp EcanDbParams
